sequencetools.yield_all_pairs_between_sequences
===============================================

.. autofunction:: abjad.tools.sequencetools.yield_all_pairs_between_sequences.yield_all_pairs_between_sequences
